<?php

namespace EventPortal\Domain\ActionList\Models;

use EventPortal\Domain\User\Models\User;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\HasMany;
use Illuminate\Support\Facades\Auth;

class ActionList extends Model
{
    /** @var array */
    protected $fillable = [
        'event_id',
        'status',
        'type',
    ];

    public function tasks(): HasMany
    {
        return $this->hasMany(Task::class);
    }

    public function complete(?User $user = null): void
    {
        $this->tasks()->incomplete()->each(function (Task $task) use ($user): void {
            $task->setAsComplete($user ?? Auth::user());
        });
    }

    public function getNumOutstandingTasksAttribute(): int
    {
        return (int) $this->tasks()->incomplete()->count();
    }
}
