<?php

namespace EventPortal\Tests\Feature\Admin\Permission;

use EventPortal\Domain\Permission\Models\Role;
use EventPortal\Tests\Support\Traits\SeedRolesAndPermissions;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\RefreshDatabase;

class RoleStoreTest extends TestCase
{
    use RefreshDatabase, SeedRolesAndPermissions;

    /** @test */
    public function can_create_roles(): void
    {
        $this
            ->actingAsSuperAdmin()
            ->post(route('admin.role.store'), [
                'name' => 'My role name',
            ])
            ->assertRedirect(route('admin.permission.index'));

        $role = Role::whereName('my-role-name')->first();

        $this->assertEquals('My role name', $role->label);
        $this->assertEquals('my-role-name', $role->name);
        $this->assertEquals('web', $role->guard_name);
    }

    /** @test */
    public function must_have_name(): void
    {
        $response = $this
            ->actingAsSuperAdmin()
            ->post(route('admin.role.store'), ['name' => '']);

        $response->assertSessionHasErrors(['name' => 'The name field is required.']);
    }

    /** @test */
    public function must_be_unique(): void
    {
        factory(Role::class)->create([
            'label' => 'My role name',
            'name' => 'my-role-name',
        ]);

        $response = $this
            ->actingAsSuperAdmin()
            ->post(route('admin.role.store'), [
                'name' => 'My role name',
            ]);

        $response->assertSessionHasErrors(['name' => 'The name has already been taken.']);
    }

    /** @test */
    public function name_must_be_alpha(): void
    {
        $response = $this
            ->actingAsSuperAdmin()
            ->post(route('admin.role.store'), [
                'name' => 1234,
            ]);

        $response->assertSessionHasErrors(['name' => 'The name may only contain letters.']);
    }
}
